pub struct VacantEntry<'a, T, S, A: Allocator = Global> {
base: VacantEntry<'a, T, S, A>,
}🔬This is a nightly-only experimental API. (
hash_set_entry #60896)Expand description
A view into a vacant entry in a HashSet.
It is part of the Entry enum.
Examples
#![feature(hash_set_entry)]
use std::collections::hash_set::{Entry, HashSet};
let mut set = HashSet::<&str>::new();
let entry_v = match set.entry("a") {
Entry::Vacant(view) => view,
Entry::Occupied(_) => unreachable!(),
};
entry_v.insert();
assert!(set.contains("a") && set.len() == 1);
// Nonexistent key (insert)
match set.entry("b") {
Entry::Vacant(view) => view.insert(),
Entry::Occupied(_) => unreachable!(),
}
assert!(set.contains("b") && set.len() == 2);Fields
base: VacantEntry<'a, T, S, A>🔬This is a nightly-only experimental API. (
hash_set_entry #60896)Implementations
Sourceimpl<'a, T, S, A: Allocator> VacantEntry<'a, T, S, A>
impl<'a, T, S, A: Allocator> VacantEntry<'a, T, S, A>
Sourcepub fn get(&self) -> &T
🔬This is a nightly-only experimental API. (hash_set_entry #60896)
pub fn get(&self) -> &T
hash_set_entry #60896)Gets a reference to the value that would be used when inserting
through the VacantEntry.
Examples
Sourcepub fn into_value(self) -> T
🔬This is a nightly-only experimental API. (hash_set_entry #60896)
pub fn into_value(self) -> T
hash_set_entry #60896)Take ownership of the value.
Examples
Sourcepub fn insert(self)where
T: Hash,
S: BuildHasher,
🔬This is a nightly-only experimental API. (hash_set_entry #60896)
pub fn insert(self)where
T: Hash,
S: BuildHasher,
hash_set_entry #60896)Sets the value of the entry with the VacantEntry’s value.
Examples
fn insert_entry(self) -> OccupiedEntry<'a, T, S, A>where
T: Hash,
S: BuildHasher,